@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2005-2022 Intel Corporation
+    Copyright (c) 2005-2024 Intel Corporation
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -1928,7 +1928,7 @@ public:
     }
 };
 
-// test from user ahelwer: http://software.intel.com/en-us/forums/showthread.php?t=103786
+// test from user ahelwer: https://community.intel.com/t5/Intel-oneAPI-Threading-Building/Exception-in-flow-graph-results-in-graph-wait-for-all-hanging/td-p/789352
 // exception thrown in graph node, not caught in wait_for_all()
 void
 test_flow_graph_exception0() {
@@ -2017,6 +2017,7 @@ void TestOneThreadNum(int nThread) {
     );
 }
 
+#if !EMSCRIPTEN
 //! Test exceptions with parallelism
 //! \brief \ref error_guessing
 TEST_CASE("Testing several threads"){
@@ -2026,5 +2027,5 @@ TEST_CASE("Testing several threads"){
         TestOneThreadNum(nThread);
     }
 }
-
+#endif
 #endif // TBB_USE_EXCEPTIONS
